@@ -34,10 +34,11 @@ class FloatInputPort(InputPort[float]):
     pass
 
 
-class JsonInputPort(InputPort[json]):
+class JsonInputPort(InputPort[dict]):
 
-    def parse(self, message) -> json:
-        return json.loads(message)
+    pass
+    # def parse(self, message) -> json:
+    #     return json.loads(message)
 
 
 class RecordInputPort(InputPort[Record]):
